==> chromium-browser_25.0.1364.160.orig.tar.xz: chromium-browser-25.0.1364.160/src/content/public/test/android/javatests/src/org/chromium/content/browser/test/util/TestContentViewClient.java <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.content.browser.test.util;

import android.content.Context;

import org.chromium.content.browser.ContentViewClient;
import org.chromium.content.browser.test.util.TestCallbackHelperContainer.OnEvaluateJavaScriptResultHelper;
import org.chromium.content.browser.test.util.TestCallbackHelperContainer.OnStartContentIntentHelper;

/**
 * The default ContentViewClient used by ContentView tests.
 * <p>
 * Tests that need to supply their own ContentViewClient should do that
 * by extending this one.
 */
public class TestContentViewClient extends ContentViewClient {

    private OnEvaluateJavaScriptResultHelper mOnEvaluateJavaScriptResultHelper;
    private OnStartContentIntentHelper mOnStartContentIntentHelper;

    public TestContentViewClient() {
        mOnEvaluateJavaScriptResultHelper = new OnEvaluateJavaScriptResultHelper();
        mOnStartContentIntentHelper = new OnStartContentIntentHelper();
    }

    public OnEvaluateJavaScriptResultHelper getOnEvaluateJavaScriptResultHelper() {
        return mOnEvaluateJavaScriptResultHelper;
    }

    public OnStartContentIntentHelper getOnStartContentIntentHelper() {
        return mOnStartContentIntentHelper;
    }

    /**
     * ATTENTION!: When overriding the following methods, be sure to call
     * the corresponding methods in the super class. Otherwise
     * {@link CallbackHelper#waitForCallback()} methods will
     * stop working!
     */
    @Override
    public void onEvaluateJavaScriptResult(int id, String jsonResult) {
        super.onEvaluateJavaScriptResult(id, jsonResult);
        mOnEvaluateJavaScriptResultHelper.notifyCalled(id, jsonResult);
    }

    @Override
    public void onStartContentIntent(Context context, String contentUrl) {
        mOnStartContentIntentHelper.notifyCalled(contentUrl);
    }
}

==> chromium-browser_31.0.1650.63.orig.tar.xz: chromium-browser-31.0.1650.63/src/content/public/test/android/javatests/src/org/chromium/content/browser/test/util/TestContentViewClient.java <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.content.browser.test.util;

import android.content.Context;

import org.chromium.content.browser.ContentViewClient;
import org.chromium.content.browser.test.util.TestCallbackHelperContainer.OnEvaluateJavaScriptResultHelper;
import org.chromium.content.browser.test.util.TestCallbackHelperContainer.OnStartContentIntentHelper;

/**
 * The default ContentViewClient used by ContentView tests.
 * <p>
 * Tests that need to supply their own ContentViewClient should do that
 * by extending this one.
 */
public class TestContentViewClient extends ContentViewClient {

    private OnEvaluateJavaScriptResultHelper mOnEvaluateJavaScriptResultHelper;
    private OnStartContentIntentHelper mOnStartContentIntentHelper;

    public TestContentViewClient() {
        mOnEvaluateJavaScriptResultHelper = new OnEvaluateJavaScriptResultHelper();
        mOnStartContentIntentHelper = new OnStartContentIntentHelper();
    }

    public OnEvaluateJavaScriptResultHelper getOnEvaluateJavaScriptResultHelper() {
        return mOnEvaluateJavaScriptResultHelper;
    }

    public OnStartContentIntentHelper getOnStartContentIntentHelper() {
        return mOnStartContentIntentHelper;
    }

    /**
     * ATTENTION!: When overriding the following method, be sure to call
     * the corresponding method in the super class. Otherwise
     * {@link CallbackHelper#waitForCallback()} methods will
     * stop working!
     */

    @Override
    public void onStartContentIntent(Context context, String contentUrl) {
        mOnStartContentIntentHelper.notifyCalled(contentUrl);
    }
}
